package com.warewms.ams.ndc.service.impl;

import cn.hutool.core.util.ObjectUtil;
import com.warewms.ams.common.AmsConstant;
import com.warewms.ams.ndc.domain.AmsTask;
import com.warewms.ams.ndc.service.IAmsTaskService;
import com.warewms.ams.ndc.service.StatusUpdateService;
import com.warewms.common.utils.string.StringUtils;
import lombok.extern.slf4j.Slf4j;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Component;

@Slf4j
@Component
public class StatusUpdateServiceImpl implements StatusUpdateService {

    @Autowired
    private IAmsTaskService amsTaskService;

    @Override
    public void taskStateResponse(Integer state, Integer carNo, Integer aciIndex) {
        AmsTask amsTask = amsTaskService.getAmsTaskByAciIndex(aciIndex);
        log.info("taskStateResponse - amsTask is :{}, state is :{}", amsTask, state);
        if (ObjectUtil.isNull(amsTask)) {
            return;
        }
        //如果任务为第一段任务 则不下发2 4 6状态至wms
        if (StringUtils.isNotBlank(amsTask.getExt3()) && (state.equals(AmsConstant.TASK_STS.TASK2.getValue())
                || state.equals(AmsConstant.TASK_STS.TASK6.getValue()) || state.equals(AmsConstant.TASK_STS.TASK4.getValue()))) {
            return;
        }
        //如果任务为第二段任务 则不下发任务开始状态至wms
        if (StringUtils.isBlank(amsTask.getExt3()) && state.equals(AmsConstant.TASK_STS.TASK1.getValue())){
            return;
        }
        amsTaskService.amsStateFeedbackToWms(state, String.valueOf(amsTask.getId()), amsTask.getTaskNo(), carNo);
    }

    @Override
    public void updateStatus(Long id, Integer carNo, Integer state) {
        AmsTask amsTask = amsTaskService.selectAmsTaskById(id);
        if (ObjectUtil.isNull(amsTask)) return;

        log.info("任务回调-------------------------》" + amsTask.getTaskNo());
        if (amsTask.getAciIndex() == null) {
            log.error("没有index，未下发的任务");
        }
        if (StringUtils.isNotBlank(amsTask.getExt3()) &&
                state.equals(AmsConstant.TASK_STS.TASK2.getValue())) {
            amsTaskService.ndcAmsTaskInsert(amsTask.getTaskNo(), amsTask.getBusinessType(), amsTask.getStTo(), amsTask.getExt3());
        }
    }
}
